System.register([], (function (exports) {
	'use strict';
	return {
		execute: (function () {

			const TEST_MODULE_B = exports('TEST_MODULE_B', 'A');

		})
	};
}));
